package
module
Version:
v0.0.0-...-4503694
Opens a new window with list of versions in this module.
Published: May 25, 2017
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
IsDocker 
Check if the process is running inside a Docker container
How to use it
package main
import (
"fmt"
. "github.com/dlion/IsDocker"
)
func main() {
if IsDocker() {
fmt.Println("Info: Running inside a docker container")
}
}
Test
go test
Author
Domenico Luciani
https://domenicoluciani.com
License
MIT
Documentation
¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.